ams.core.service.MinDur
=======================

.. currentmodule:: ams.core.service

.. autoclass:: MinDur

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~MinDur.assign_memory
       
       
          ~MinDur.evaluate
       
       
          ~MinDur.get_names
       
       
          ~MinDur.parse
       
       
          ~MinDur.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~MinDur.class_name
      ~MinDur.n
      ~MinDur.shape
      ~MinDur.size
      ~MinDur.v
      ~MinDur.v0
      ~MinDur.v1
   
   